.. _target_users:

============
Target Users
============

Cloud end users want to simply use applications as
opposed to installing and managing them. Cloud administrators,
in turn, would like to offer a well tested set of on demand
self-service applications to dramatically reduce their support burden.

Murano solves the problems of both constituents.
It enables cloud administrators to publish cloud-ready
applications in an online catalog. Cloud end users can use
the catalog to deploy these on demand applications, reliably
and consistently, with a button click.


Cloud administrators
~~~~~~~~~~~~~~~~~~~~

For cloud administrators Murano provides UI and
API to easily compose, deploy, run applications, and manage
their lifecycle.

Designed to be operating system independent, it can handle apps on all
manner of the environments in the cloud, either Windows
or Linux/Unix-based operating systems.

It can be used to pre-configure and deploy anything that can
run in the cloud,
from low-level networking services to end-user applications.
By automating these ongoing cloud application management
activities, Murano speeds up the deployment, even for complex
distributed applications, without sacrificing simplicity
of use.



Cloud end users
~~~~~~~~~~~~~~~

Murano catalog lets cloud end users choose
from the available applications and services, and compose
reliable distributed environments with an intuitive UI.
Even users unfamiliar with cloud environments can easily
deploy cloud-aware applications.

Murano masks cloud-infrastructure specifics from end
users, letting them reliably compose and deploy
applications in the cloud for the widest range of
workloads and use cases without touching IaaS internals.


